REM SATILL.BAS
REM Program to calculate eclipse state of satellite from Kepler.
REM Counts sunlight and darkness states at two minute intervals
REM during each day of survey.
REM
REM Written by C.Wallis G3CWV
REM Created 24-January-1998
REM V1.0 07-April-1998
REM V1.1 06-January-2001    Year 2000+ correction added to sub Save_Keps
REM V1.2 28-March-2001  restored INT's, was FIXs
REM
REM Basic Interpreter required ... QBASIC

REM Input files    1.    Single Keplerian element, two line format

REM Output file   Day number, Sun count, Eclipse count.

REM Program is based on James Miller's PLAN13 code, which has been
REM converted to QBASIC.   Much of the orignal code, including some
REM line numbers has been left in the program. Some of this code is
REM redundant, and could be removed.

REM The program also includes code from OZFORM.BAS, by C.Wallis.
REM This is used to extract the orbital data from the two line
REM Keplerian elements.


REM 10 T$ = "PLAN13"
REM  OSCAR-13 POSITION, SUN + ECLIPSE PLANNER
20 REM
30 IS$ = "v2.0": REM Last mod 1992 Jan 14 by JRM
40 REM
50 REM        (C)1992 J.R. Miller G3RUH
60 REM
70 REM Proceeds from the sale of this software go directly to the
80 REM Amateur Satellite Programme that helped fund AO-13.
90 REM If you take a copy PLEASE also send a small donation to:
100 REM         AMSAT-UK, LONDON, E12 5EQ.

ON ERROR GOTO error.trap
TRUE = -1
FALSE = 0

CONST PI = 3.141592646#

4220 DEF FNARCTAN (Y, X)
4230 IF X = 0 THEN
        A = PI / 2 * SGN(Y)
        GOTO 4260
        END IF
4240 A = ATN(Y / X)
     IF X < 0 THEN
     A = A + PI
     GOTO 4260
     END IF
4250 IF A < 0 THEN A = A + 2 * PI
4260 FNARCTAN = A
 END DEF


5000 DEF FNdate$ (D)
5010 REM Day-number to date; valid 1900 Mar 01 - 2100 Feb 28
5020 D = D + 428: DW = (D + 5) MOD 7
5030 Y = INT((D - 122.1) / YM): D = D - INT(Y * YM)
5040 MN = INT(D / 30.61): D = D - INT(MN * 30.6)
5050 MN = MN - 1: IF MN > 12 THEN MN = MN - 12: Y = Y + 1
5060 D$ = STR$(Y) + " " + MID$("JanFebMarAprMayJunJulAugSepOctNovDec", 3 * MN - 2, 3)
5070 FNdate$ = D$ + " " + STR$(D) + " [" + MID$("SunMonTueWedThuFriSat", 3 * DW + 1, 3) + "]"
 END DEF

 DEF FNday (Y, M, D)
5100 REM Date to day-number
5110 IF M <= 2 THEN Y = Y - 1: M = M + 12
5120 FNday = INT(Y * YM) + INT((M + 1) * 30.6) + D - 428
 END DEF

6270 DEF FNrn (X) = INT(X + .5)

     DEF FNRAD (X) = X / 180 * PI

     DEF FNDEG (X) = X / PI * 180

DEF FNASN (X)

REM Returns angle in radians from value of SIN(X)

IF (X < 1) AND (X > -1) THEN
    angle = ATN(X / SQR(1 - X * X))

ELSEIF X = 1 THEN angle = PI / 2
ELSEIF X = -1 THEN angle = -PI / 2
END IF
FNASN = angle
END DEF

DEF FNACS (X)

REM Returns angle in radians from value of COS(X)

IF (X < 1) AND (X > -1) THEN
    angle = PI / 2 - ATN(X / SQR(1 - X * X))

ELSEIF X = 1 THEN angle = 0
ELSEIF X = -1 THEN angle = PI
END IF
FNACS = angle
END DEF


REM    ------------- MAIN PROGRAM LOOP -------------
PRINT
INPUT "Enter name of output file  ", out.File$
OPEN out.File$ FOR OUTPUT AS #3
PRINT
GOSUB init: REM Set up constants

INPUT "Enter start date (e.g. 1992, 12, 25)  ", YR, MN, DY
PRINT
INPUT "Enter number of days for printout  ", ND
PRINT
INPUT "Enter sampling interval .. Days  ", SD
PRINT
170 DS = FNday(YR, MN, DY): REM Start  day No.
180 DF = DS + ND - 1:       REM Finish day No.

PRINT "         Date          Day No.       Sun          Dark        %Sun"
PRINT "----------------------------------------------------------------------"
FOR DN = DS TO DF STEP SD
  ECLCOUNT = 0
  SUNCOUNT = 0
  FOR HR = 0 TO 23
    FOR MIN = 0 TO 58 STEP 2
      TN = (HR + MIN / 60) / 24
      GOSUB satvec
      GOSUB rangevec
      GOSUB sunvec
      IF SUN <> 1 THEN ECLCOUNT = ECLCOUNT + 1 ELSE SUNCOUNT = SUNCOUNT + 1
    NEXT
  NEXT
format1$ = "\                 \      ###         ###          ###          ##.#"
  PRINT USING format1$; FNdate$(DN); DN - FNday(YR, 1, 1) + 1; SUNCOUNT; ECLCOUNT; SUNCOUNT / (SUNCOUNT + ECLCOUNT) * 100

format2$ = "#### ### ###"
PRINT #3, USING format2$; DN - FNday(YR, 1, 1) + 1; SUNCOUNT; ECLCOUNT
REM PRINT, USING format2$;DN - FNday(YR,1,1)+1, SUNCOUNT,ECLCOUNT
NEXT
SYSTEM

1000 init:
1010 REM SATELLITE EPHEMERIS
1020 REM -------------------
GOSUB getkeps



1030 REM SAT$ = "OSCAR-11"
1040 REM YE = 1996: REM Epoch Year   year
1050 REM TE = 1.5: REM Epoch time   days
1060 REM IN = 98!: REM Inclination  deg
1070 REM RA = 0: REM R.A.A.N.     deg
1080 REM EC = 0: REM Eccentricity  -
1090 REM WP = 0: REM Arg perigee  deg
1100 REM MA = 0: REM Mean anomaly deg
1110 REM MM = 15.6: REM Mean motion  rev/d
1120 REM M2 = .001: REM Decay Rate   rev/d/d
1130 REM RV = 0: REM Orbit number  -
1140 ALON = 180: REM Sat attitude deg. 180 = nominal ) See bulletins
1150 ALAT = 0: REM Sat attitude deg.   0 = nominal ) for latest
1160
1170 REM Observer's location + North, + East, ASL(m)
1180 LOC$ = "G3CWV": LA = 51.975: LO = -.29: HT = 0: REM Ickleford, UK
1190
1200 LA = FNRAD(LA): LO = FNRAD(LO): HT = HT / 1000
1210 CL = COS(LA): SL = SIN(LA): CO = COS(LO): SO = SIN(LO)
1220 RE = 6378.14: FL = 1 / 298.257:    REM IAU-76 Earth ellipsoid
1230 RP = RE * (1 - FL): XX = RE * RE: ZZ = RP * RP
1240 D = SQR(XX * CL * CL + ZZ * SL * SL)
1250 Rx = XX / D + HT: Rz = ZZ / D + HT
1260
1270 REM Observer's unit vectors UP EAST and NORTH in GEOCENTRIC coords.
1280 Ux = CL * CO: Ex = -SO: Nx = -SL * CO
1290 Uy = CL * SO: Ey = CO: Ny = -SL * SO
1300 Uz = SL: Ez = 0: Nz = CL
1310
1320 REM Observer's XYZ coords at Earth's surface
1330 Ox = Rx * Ux: Oy = Rx * Uy: Oz = Rz * Uz
1340
1350 REM Convert angles to radians etc.
1360 RA = FNRAD(RA): in = FNRAD(in): WP = FNRAD(WP)
1370 MA = FNRAD(MA): MM = MM * 2 * PI: M2 = M2 * 2 * PI
1380
1390 YM = 365.25:     REM Mean Year,     days
1400 YT = 365.242197#: REM Tropical year, days
1410 WW = 2 * PI / YT: REM Earth's rotation rate, rads/whole day
1420 WE = 2 * PI + WW: REM  ditto  rads/d
1430 W0 = WE / 86400: REM  ditto  rads/sec
1440
1450 VOx = -Oy * W0: VOy = Ox * W0: REM Observer's velocity, GEOCENTRIC coords. (VOz=0)
1460
1470 REM Convert satellite Epoch to Day No. and Fraction of day
1480 DE = FNday(YE, 1, 0) + INT(TE): TE = TE - INT(TE)
1490
1500 REM Average Precession rates
1510 GM = 398600!:    REM Earth's Gravitational constant km^3/s^2
1520 J2 = 1.08263E-03: REM 2nd Zonal coeff, Earth's Gravity Field
1530 N0 = MM / 86400: REM Mean motion rad/s
1540 A0 = (GM / N0 / N0) ^ (1 / 3): REM Semi major axis km
1550 B0 = A0 * SQR(1 - EC * EC)
1560 SI = SIN(in): CI = COS(in)
1570 PC = RE * A0 / (B0 * B0): PC = 1.5 * J2 * PC * PC * MM: REM Precession const, rad/Day
1580 QD = -PC * CI:          REM Node precession rate, rad/day
1590 WD = PC * (5 * CI * CI - 1) / 2: REM Perigee precession rate, rad/day
1600 DC = -2 * M2 / MM / 3: REM Drag coeff. (Angular momentum rate)/(Ang mom)  s^-1
1610
1620 REM Sidereal and Solar data. NEVER needs changing. Valid to year 2000+
1630 YG = 1990: G0 = 99.4033:  REM GHAA, Year YG, Jan 0.0
1640 MAS0 = 356.6349: MASD = .9856002699999999#: REM MA Sun and rate, deg, deg/day
1650 INS = FNRAD(23.4406): CNS = COS(INS): SNS = SIN(INS): REM Sun's inclination
1660 EQC1 = .03343: EQC2 = .00034: REM Sun's Equation of centre terms
1670
1680 REM Bring Sun data to Satellite Epoch
1690 TEG = (DE - FNday(YG, 1, 0)) + TE: REM Elapsed Time: Epoch - YG
1700 GHAE = FNRAD(G0) + TEG * WE:      REM GHA Aries, epoch
1710 MRSE = FNRAD(G0) + TEG * WW + PI: REM Mean RA Sun at Sat epoch
1720 MASE = FNRAD(MAS0 + MASD * TEG):  REM Mean MA Sun  ..
1730
1740 REM Antenna unit vector in orbit plane coordinates.
1750 CO = COS(FNRAD(ALON)): SO = SIN(FNRAD(ALON))
1760 CL = COS(FNRAD(ALAT)): SL = SIN(FNRAD(ALAT))
1770 Kax = -CL * CO: Kay = -CL * SO: Kaz = -SL
1780
1790 REM Misc
1800 REM ******@%=&507: REM 5 decimals, field 7
1810 OLDRN = -99999
1820 REM PRINT T$; " "; IS$; "   SATELLITE PREDICTIONS"
1830 REM PRINT STRING$(35, "-")
1840
1850 RETURN: REM    End of INIT


2000 satvec:
2010 REM Calculate Satellite Position at DN,TN
2020 T# = (DN - DE) + (TN - TE): REM Elapsed T since epoch, days
2030 DT = DC * T# / 2: KD = 1 + 4 * DT: KDP = 1 - 7 * DT: REM Linear drag terms
2040 M = MA + MM * T# * (1 - 3 * DT): REM Mean anomaly at YR,TN
2050 DR = INT(M / (2 * PI)):  REM Strip out whole no of revs
2060 M = M - DR * 2 * PI:     REM M now in range 0 - 2pi
2070 RN = RV + DR:            REM Current Orbit number
2080
2090 REM Solve M = EA - EC*SIN(EA) for EA given M, by Newton's Method
2100 EA = M:               REM Initial solution
2110 DO
2120 C = COS(EA): S = SIN(EA): DNOM = 1 - EC * C
2130 D = (EA - EC * S - M) / DNOM: REM Change to EA for better solution
2140 EA = EA - D:          REM by this amount
2150 LOOP UNTIL ABS(D) < .00001: REM Until converged
2160
2170 A = A0 * KD: B = B0 * KD: RS = A * DNOM: REM Distances
2180
2190 REM Calc satellite position & velocity in plane of ellipse
2200 Sx = A * (C - EC): Vx = -A * S / DNOM * N0
2210 Sy = B * S:    Vy = B * C / DNOM * N0
2220
2230 AP = WP + WD * T# * KDP: CW = COS(AP): SW = SIN(AP)
2240 RAAN = RA + QD * T# * KDP: CQ = COS(RAAN): SQ = SIN(RAAN)
2250
2260 REM Plane -> celestial coordinate transformation, [C] = [RAAN]*[IN]*[AP]
2270 CXx = CW * CQ - SW * CI * SQ: CXy = -SW * CQ - CW * CI * SQ: CXz = SI * SQ
2280 CYx = CW * SQ + SW * CI * CQ: CYy = -SW * SQ + CW * CI * CQ: CYz = -SI * CQ
2290 CZx = SW * SI:      CZy = CW * SI:       CZz = CI
2300
2310 REM Compute SATellite's position vector, ANTenna axis unit vector
2320 REM and VELocity in CELESTIAL coordinates. (Note: Sz=0, Vz=0)
2330 SATx = Sx * CXx + Sy * CXy: ANTx = Kax * CXx + Kay * CXy + Kaz * CXz: VELx = Vx * CXx + Vy * CXy
2340 SATy = Sx * CYx + Sy * CYy: ANTy = Kax * CYx + Kay * CYy + Kaz * CYz: VELy = Vx * CYx + Vy * CYy
2350 SATz = Sx * CZx + Sy * CZy: ANTz = Kax * CZx + Kay * CZy + Kaz * CZz: VELz = Vx * CZx + Vy * CZy
2360
2370 REM Also express SAT,ANT and VEL in GEOCENTRIC coordinates:
2380 GHAA = GHAE + WE * T#:         REM GHA Aries at elapsed time T
2390 C = COS(-GHAA): S = SIN(-GHAA)
2400 Sx = SATx * C - SATy * S: Ax = ANTx * C - ANTy * S: Vx = VELx * C - VELy * S
2410 Sy = SATx * S + SATy * C: AY = ANTx * S + ANTy * C: Vy = VELx * S + VELy * C
2420 Sz = SATz:          Az = ANTz:          Vz = VELz
2430 RETURN
2440
3000 sunvec:
3010 MAS = MASE + FNRAD(MASD * T):     REM MA of Sun round its orbit
3020 TAS = MRSE + WW * T# + EQC1 * SIN(MAS) + EQC2 * SIN(2 * MAS)
3030 C = COS(TAS): S = SIN(TAS):     REM Sin/Cos Sun's true anomaly
3040 SUNx = C: SUNy = S * CNS: SUNz = S * SNS: REM Sun unit vector - CELESTIAL coords
3050
3060 REM Find Solar angle, illumination, and eclipse status.
3070 SSA = -(ANTx * SUNx + ANTy * SUNy + ANTz * SUNz): REM Sin of Sun angle -a.h
3080 ILL = SQR(1 - SSA * SSA):                  REM Illumination
3090 CUA = -(SATx * SUNx + SATy * SUNy + SATz * SUNz) / RS: REM Cos of umbral angle -h.s
3100 UMD = RS * SQR(1 - CUA * CUA) / RE:        REM Umbral dist, Earth radii
     ECL = 1: REM Set flag for sunshine state
3110 IF CUA >= 0 THEN ECL$ = "    +" ELSE ECL$ = "    -": REM + for shadow side
3120 IF UMD <= 1 AND CUA >= 0 THEN
                                 ECL$ = "   ECL": REM - for sunny side
                                 SUN = 0
                               ELSE
                                 SUN = 1
                              END IF
3130
3140 REM Obtain SUN unit vector in GEOCENTRIC coordinates
3150 C = COS(-GHAA): S = SIN(-GHAA)
3160 Hx = SUNx * C - SUNy * S
3170 Hy = SUNx * S + SUNy * C
3180 Hz = SUNz: REM satellite possibly visible
3190 IF (Hx * Ux + Hy * Uy + Hz * Uz < -.17) AND (ECL$ <> "   ECL") THEN ECL$ = "   vis"
3200
3210 REM Obtain Sun unit vector in ORBIT coordinates
3220 Hx = SUNx * CXx + SUNy * CYx + SUNz * CZx
3230 Hy = SUNx * CXy + SUNy * CYy + SUNz * CZy
3240 Hz = SUNx * CXz + SUNy * CYz + SUNz * CZz
3250 SEL = FNASN(Hz): SAZ = FNARCTAN(Hy, Hx)
3260 RETURN
3270
4000 rangevec:
4010 REM Compute and manipulate range/velocity/antenna vectors
4020 Rx = Sx - Ox: Ry = Sy - Oy: Rz = Sz - Oz: REM Rangevec = Satvec - Obsvec
4030 R = SQR(Rx * Rx + Ry * Ry + Rz * Rz): REM Range magnitude
4040 Rx = Rx / R: Ry = Ry / R: Rz = Rz / R: REM Normalise Range vector
4050 U = Rx * Ux + Ry * Uy + Rz * Uz: REM UP  Component of unit range
4060 E = Rx * Ex + Ry * Ey: REM EAST   .. (Ez=0)
4070 N = Rx * Nx + Ry * Ny + Rz * Nz: REM NORTH  ..
4080 AZim = FNDEG(FNARCTAN(E, N)): REM Azimuth
4090 EL = FNDEG(FNASN(U)):      REM Elevation
4100
4110 REM Resolve antenna vector along unit range vector, -r.a = Cos(SQ)
4120 SQ = FNDEG(FNACS(-(Ax * Rx + AY * Ry + Az * Rz))): REM Hi-gain ant SQuint
4130
4140 REM Calculate sub-satellite Lat/Lon
4150 SLON = FNDEG(FNARCTAN(Sy, Sx)): REM Lon, + East
4160 SLAT = FNDEG(FNASN(Sz / RS)): REM Lat, + North
4170
4180 REM Resolve Sat-Obs velocity vector along unit range vector. (VOz=0)
4190 RR = (Vx - VOx) * Rx + (Vy - VOy) * Ry + Vz * Rz: REM Range rate, km/s
4200 RETURN
4210
4270
4280 mode:
4290 M = INT(M * 128 / PI)
4300 REM Mode switching MA/256
4310 MD$ = "-"
4320 IF M >= 0 THEN MD$ = "B"
4330 IF M >= 100 THEN MD$ = "L"
4340 IF M >= 130 THEN MD$ = "S"
4350 IF M >= 135 THEN MD$ = "B"
4360 IF M >= 220 THEN MD$ = "-"
4370 RETURN
4380
5080
5095130
6000 printdata:
6010 REM Time as a string
6020 HR$ = STR$(HR): MIN$ = STR$(MIN)
6030 IF LEN(HR$) < 2 THEN HR$ = "0" + HR$
6040 IF LEN(MIN$) < 2 THEN MIN$ = "0" + MIN$
6050 TIM$ = HR$ + MIN$ + "  "
6060
6070 GOSUB mode
6080 R = FNrn(R): EL = FNrn(EL): AZim = FNrn(AZim): SQ = FNrn(SQ): RR = FNrn(RR * 10) / 10
6090 HGT = FNrn(RS - RE): SLON = FNrn(SLON): SLAT = FNrn(SLAT)
6100 IF RN <> OLDRN THEN OLDRN = RN: GOSUB header
format$ = "\    \  \   \ & ##### ## ### ### ### & ##### ### ###"
6110 REM PRINT USING format$; TIM$; STR$(M); MD$; R; EL; AZim; SQ; RR; ECL$; HGT; SLAT; SLON
PRINT wod.line.no; "   "; SLAT; "  "; SLON; "  "; HGT

6120 RETURN
6130
6140 header:
PRINT "WOD NO    LAT    LON   HGT"
GOTO 6250

6150 RAAN = FNrn(FNDEG(RAAN)): AP = FNrn(FNDEG(AP)): SAZ = FNrn(FNDEG(SAZ))
6160 SEL = FNrn(FNDEG(SEL)): ILL = FNrn(100 * ILL)
6170 PRINT : PRINT
6180 PRINT sat$; "  -  "; LOC$; SPC(16); "AMSAT DAY; "; STR$(DN - 722100); SPC(12); FNdate$(DN); ""
6190 PRINT "ORBIT: "; RN; "   AP/RAAN: "; AP; "/"; RAAN; "   ALON/ALAT: "; ALON; "/"; ALAT;
6200 PRINT "   SAZ/SEL: "; SAZ; "/"; SEL; "   ILL: "; ILL; "%"
6210 PRINT
6220 PRINT " UTC  MA  MODE  RANGE     EL     AZ     SQ     RR  ECL?    ";
6230 PRINT "HGT    SLAT   SLON"
6240 PRINT STRING$(77, "-")
6250 RETURN
6260

getkeps:

REM Extracts Keps from a file of two line elements
REM Code from OZFORM.BAS by C.Wallis G3CWV, 28-June-94
REM ------
INPUT "Enter Kepler file name  ", in.File$
OPEN in.File$ FOR INPUT AS #1
REM INPUT "Enter name of output file "; out.File$
REM OPEN out.File$ FOR OUTPUT AS #2
sat.name$ = "": line1$ = "": line2$ = ""
chk% = FALSE
PRINT
REM PRINT #2, "--------------------------------------------------------------------------------"
REM PRINT #2, "NAME         EPOCH    INCL   RAAN  ECCY   ARGP    MA      MM      DCY      REVN"
PRINT "NAME         EPOCH    INCL   RAAN  ECCY   ARGP    MA      MM      DCY      REVN"
REM PRINT #2, "--------------------------------------------------------------------------------"
PRINT
DO              'Main program loop
 sat.name$ = line1$
 line1$ = line2$
 INPUT #1, line$
 line2$ = line$
 IF NOT EOF(1) THEN GOSUB check
 IF chk% THEN GOSUB save.kep
LOOP UNTIL EOF(1)
CLOSE #1
RETURN
REM ------
check:
 REM Checks that three lines of data are correct
 REM Inputs sat.name$, line1$, line2$
 REM Output chk% ... TRUE if OK
 chk% = TRUE
 IF LEN(sat.name$) > 12 THEN chk% = FALSE
 IF VAL(LEFT$(line1$, 1)) <> 1 THEN chk% = FALSE
 IF VAL(LEFT$(line2$, 1)) <> 2 THEN chk% = FALSE
 IF ((LEN(line1$) <> 69) OR (LEN(line2$) <> 69)) THEN chk% = FALSE
 line$ = line1$
 GOSUB check.sum
 line$ = line2$
 GOSUB check.sum
RETURN
REM ------
check.sum:
 REM Tests line of data for checksum
 REM Input line$
 REM Output chk% (Only set to false if checksum fails)
 sum% = 0
 FOR I% = 1 TO 68
  ch$ = MID$(line$, I%, 1)
  SELECT CASE ch$
    CASE "+"
        sum% = sum% + 2
    CASE "-"
        sum% = sum% + 1
    CASE ELSE
        sum% = sum% + VAL(ch$)
  END SELECT
 NEXT I%
 ch$ = MID$(line$, 69, 1)
 sum% = (sum% MOD 10)
 IF sum% <> VAL(ch$) THEN chk% = FALSE
RETURN
REM-------
save.kep:
 REM The output routine
 YE = INT(VAL(MID$(line1$, 19, 2)))
 TE# = VAL(MID$(line1$, 21, 12))
 in = VAL(MID$(line2$, 9, 8))
 RA = VAL(MID$(line2$, 18, 8))
 EC = VAL(MID$(line2$, 27, 7)) * .0000001
 WP = VAL(MID$(line2$, 35, 8))
 MA = VAL(MID$(line2$, 44, 8))
 MM# = VAL(MID$(line2$, 53, 9))
 M2 = VAL(MID$(line1$, 34, 10))
 RV = INT(VAL(MID$(line2$, 64, 5)))
 format$ = "\      \ ## ###.##### ##.## ###.## #.#### ###.## ###.## ##.##### ##.#^^^^ #####"
 PRINT
 PRINT USING format$; sat.name$; YE; TE#; in; RA; EC; WP; MA; MM#; M2; RV
 REM PRINT #2, USING format$; sat.name$; YE; TE#; IN; RA; EC; WP; MA; MM#; DC; RV
 PRINT
MM = MM#
TE = TE#
IF YE < 60 THEN YE = YE + 2000 ELSE YE = YE + 1900
sat$ = sat.name$
REM PRINT MM, TE
RETURN
REM ------
error.trap:
 SELECT CASE ERR
    CASE 53
        PRINT "File not found"
    CASE 52, 64, 76, 68
        PRINT "Bad file or path name"
    CASE 71
        PRINT "Disk not ready"
    CASE 72
        PRINT "Disk error"
 END SELECT
 PRINT "Error number  "; ERR
 SYSTEM
 REM --------------

